SystemOrganization addCategory: #'Seaside-Tests-FileSystem'!

TestCase subclass: #WAExternalFileLibraryTest
	instanceVariableNames: 'fileSystem'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-FileSystem'!

!WAExternalFileLibraryTest methodsFor: 'testing' stamp: 'NickAger 9/5/2009 14:27'!
crossPlatformPathFromArray: pathArray finalSlash: finalSlash
	| separator path|
	separator := String with: SpFilename new separator.
	
	path := String new.
	pathArray do: [:pathElement | 
		path := path, separator, pathElement ].

	finalSlash ifTrue: [ path:= path, separator]. 
	
	^ path
! !

!WAExternalFileLibraryTest methodsFor: 'private' stamp: 'lr 8/2/2009 12:50'!
requestWithUrl: aString
	^ WARequest method: 'POST' uri: aString! !

!WAExternalFileLibraryTest methodsFor: 'running' stamp: 'pmm 10/18/2008 10:39'!
setUp
	super setUp.
	fileSystem := WAExternalFileLibrary new.
	fileSystem setName: 'culture'! !

!WAExternalFileLibraryTest methodsFor: 'testing' stamp: 'pmm 10/18/2008 11:28'!
testAsAbsoluteUrlRelativeTo
	| request |
	fileSystem configuration valueAt: #directory put: '/home/philppe/pr0n'.
	request := self requestWithUrl: '/culture/pictures'.
	self assert: (fileSystem asAbsoluteUrl: 'cleopatra.jpeg' relativeTo: request) seasideString = '/culture/pictures/cleopatra.jpeg'.
	
	request := self requestWithUrl: '/culture/pictures/'.
	self assert: (fileSystem asAbsoluteUrl: 'cleopatra.jpeg' relativeTo: request) seasideString = '/culture/pictures/cleopatra.jpeg'.! !

!WAExternalFileLibraryTest methodsFor: 'testing' stamp: 'pmm 10/18/2008 11:31'!
testMimetypeForRequest
	| request |
	request := self requestWithUrl: '/culture/pictures/cleopatra.jpeg'.
	self assert: (fileSystem mimetypeForRequest: request) = 'image/jpeg' seasideMimeType.
	
	request := self requestWithUrl: '/culture/pictures/cleopatra'.
	self assert: (fileSystem mimetypeForRequest: request) = 'application/octet-stream' seasideMimeType.
	
	request := self requestWithUrl: '/culture/pictures/cleopatra.'.
	self assert: (fileSystem mimetypeForRequest: request) = 'application/octet-stream' seasideMimeType.
	
	request := self requestWithUrl: '/'.
	self assert: (fileSystem mimetypeForRequest: request) = 'application/octet-stream' seasideMimeType.
	
	request := self requestWithUrl: '/culture/pictures/cleopatra.js'.
	self assert: (fileSystem mimetypeForRequest: request) = 'application/x-javascript' seasideMimeType.! !

!WAExternalFileLibraryTest methodsFor: 'testing' stamp: 'NickAger 9/5/2009 14:36'!
testPathForRequest
	"self debug: #testPathForRequest"

	| consumer requestPath resultPath |

	"/home/philppe/files"
	requestPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files') finalSlash: false.
	fileSystem configuration valueAt: #directory put: requestPath.
	"/culture is mapped to /home/philppe/files"
	
	"If you're looking this test and it doesn't seem to make sense, keep in mind that a file name is this context is an SpFilename, which is a path."
	consumer := WAPathConsumer path: #('culture' 'cleopatra.jpeg') asOrderedCollection.
	"/home/philppe/files/cleopatra.jpeg"
	resultPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files' 'cleopatra.jpeg') finalSlash: false.
	self assert: (fileSystem filenameForConsumer: consumer) seasideString = resultPath.
	

	consumer := WAPathConsumer path: #('culture' 'cleopatra.jpeg') asOrderedCollection.
	"/home/philppe/files/"
	requestPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files') finalSlash: true.
	fileSystem configuration valueAt: #directory put: requestPath.
	
	"/home/philppe/files/cleopatra.jpeg"
	resultPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files' 'cleopatra.jpeg') finalSlash: false.
	self assert: (fileSystem filenameForConsumer: consumer) seasideString = resultPath.
	
	
	consumer := WAPathConsumer path: #('culture' 'cleopatra.jpeg') asOrderedCollection.
	"/home/philppe/files"
	requestPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files') finalSlash: false.
	fileSystem configuration valueAt: #directory put: requestPath.
	
	"/home/philppe/files/cleopatra.jpeg"
	resultPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files' 'cleopatra.jpeg') finalSlash: false.
	self assert: (fileSystem filenameForConsumer: consumer) seasideString = resultPath.
	
	
	consumer := WAPathConsumer path: #('culture' 'cleopatra.jpeg') asOrderedCollection.
	"/home/philppe/files/"
	requestPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files') finalSlash: true.
	fileSystem configuration valueAt: #directory put: requestPath.
	
	"/home/philppe/files/cleopatra.jpeg"
	resultPath := self crossPlatformPathFromArray: #('home' 'philppe' 'files' 'cleopatra.jpeg') finalSlash: false.
	self assert: (fileSystem filenameForConsumer: consumer) seasideString = resultPath.! !
